# LlamaIndex Embeddings Integration: Google

**NOTE:** This package is deprecated. Please use the `GoogleGenAIEmbedding` class instead, detailed [here](https://github.com/run-llama/llama_index/blob/main/docs/examples/embeddings/google_genai.ipynb).
